@@ -83,7 +83,7 @@ struct	evt_priv {
 
 #define init_h2fwcmd_w_parm_no_rsp(pcmd, pparm, code) \
 do {\
-	_init_listhead(&pcmd->list);\
+	INIT_LIST_HEAD(&pcmd->list);\
 	pcmd->cmdcode = code;\
 	pcmd->parmbuf = (u8 *)(pparm);\
 	pcmd->cmdsz = sizeof(*pparm);\
@@ -122,15 +122,6 @@ struct usb_suspend_parm {
 	u32 action; /* 1: sleep, 0:resume */
 };
 
-/*
- * Caller Mode: Infra, Ad-Hoc
- * Notes: To join the specified bss
- * Command Event Mode
- */
-struct joinbss_parm {
-	struct ndis_wlan_bssid_ex network;
-};
-
 /*
  * Caller Mode: Infra, Ad-HoC(C)
  * Notes: To disconnect the current associated BSS
@@ -140,15 +131,6 @@ struct disconnect_parm {
 	u32 rsvd;
 };
 
-/*
- * Caller Mode: AP, Ad-HoC(M)
- * Notes: To create a BSS
- * Command Mode
- */
-struct createbss_parm {
-	struct ndis_wlan_bssid_ex network;
-};
-
 /*
  * Caller Mode: AP, Ad-HoC, Infra
  * Notes: To set the NIC mode of RTL8711
@@ -344,6 +326,7 @@ enum _RT_CHANNEL_DOMAIN {
 	RT_CHANNEL_DOMAIN_MAX,
 };
 
+
 struct SetChannelPlan_param {
 	enum _RT_CHANNEL_DOMAIN ChannelPlan;
 };
@@ -364,6 +347,7 @@ struct getdatarate_rsp {
 	u8 datarates[NumRates];
 };
 
+
 /*
 Caller Mode: Any
 AP: AP can use the info for the contents of beacon frame
@@ -371,6 +355,7 @@ Infra: STA can use the info when sitesurveying
 Ad-HoC(M): Like AP
 Ad-HoC(C): Like STA
 
+
 Notes: To set the phy capability of the NIC
 
 Command Mode
@@ -491,6 +476,7 @@ struct getrfintfs_parm {
 
 	parm->mac[3] is the total event counts that host requested.
 
+
 	event will be the same with the cmd's param.
 
 */
@@ -783,3 +769,4 @@ struct _cmd_callback {
 #include "rtl8712_cmd.h"
 
 #endif /* _CMD_H_ */
+
